@@ -1,5 +1,6 @@
 getLeafModel = function(model) {
-  if (inherits(model, "BaseWrapperModel"))
+  if (inherits(model, "BaseWrapperModel")) {
     return(getLeafModel(model$learner.model$next.model))
+  }
   return(model)
 }
