@@ -4,6 +4,5 @@ tuneDesign = function(learner, task, resampling, measures, par.set, control, opt
   evalOptimizationStatesTune(learner, task, resampling, measures, par.set, control, opt.path,
     show.info, xs, dobs = seq_along(xs), eols = NA_integer_, remove.nas = TRUE,
     resample.fun = resample.fun)
-  makeTuneResultFromOptPath(learner, par.set, measures, control, opt.path)
+  makeTuneResultFromOptPath(learner, par.set, measures, resampling, control, opt.path)
 }
-
